@@ -51,7 +51,7 @@ class Exceptions:
 
 class IoTDeviceAdvisorClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html)
     """
 
@@ -67,20 +67,20 @@ class IoTDeviceAdvisorClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#can_paginate)
         """
 
     def create_suite_definition(
         self,
         *,
-        suiteDefinitionConfiguration: "SuiteDefinitionConfigurationTypeDef" = None,
-        tags: Mapping[str, str] = None
+        suiteDefinitionConfiguration: "SuiteDefinitionConfigurationTypeDef" = ...,
+        tags: Mapping[str, str] = ...
     ) -> CreateSuiteDefinitionResponseTypeDef:
         """
         Creates a Device Advisor test suite.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.create_suite_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.create_suite_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#create_suite_definition)
         """
 
@@ -88,31 +88,31 @@ class IoTDeviceAdvisorClient(BaseClient):
         """
         Deletes a Device Advisor test suite.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.delete_suite_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.delete_suite_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#delete_suite_definition)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#generate_presigned_url)
         """
 
     def get_suite_definition(
-        self, *, suiteDefinitionId: str, suiteDefinitionVersion: str = None
+        self, *, suiteDefinitionId: str, suiteDefinitionVersion: str = ...
     ) -> GetSuiteDefinitionResponseTypeDef:
         """
         Gets information about a Device Advisor test suite.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.get_suite_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.get_suite_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#get_suite_definition)
         """
 
@@ -122,7 +122,7 @@ class IoTDeviceAdvisorClient(BaseClient):
         """
         Gets information about a Device Advisor test suite run.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.get_suite_run)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.get_suite_run)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#get_suite_run)
         """
 
@@ -133,32 +133,32 @@ class IoTDeviceAdvisorClient(BaseClient):
         Gets a report download link for a successful Device Advisor qualifying test
         suite run.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.get_suite_run_report)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.get_suite_run_report)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#get_suite_run_report)
         """
 
     def list_suite_definitions(
-        self, *, maxResults: int = None, nextToken: str = None
+        self, *, maxResults: int = ..., nextToken: str = ...
     ) -> ListSuiteDefinitionsResponseTypeDef:
         """
         Lists the Device Advisor test suites you have created.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.list_suite_definitions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.list_suite_definitions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#list_suite_definitions)
         """
 
     def list_suite_runs(
         self,
         *,
-        suiteDefinitionId: str = None,
-        suiteDefinitionVersion: str = None,
-        maxResults: int = None,
-        nextToken: str = None
+        suiteDefinitionId: str = ...,
+        suiteDefinitionVersion: str = ...,
+        maxResults: int = ...,
+        nextToken: str = ...
     ) -> ListSuiteRunsResponseTypeDef:
         """
         Lists the runs of the specified Device Advisor test suite.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.list_suite_runs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.list_suite_runs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#list_suite_runs)
         """
 
@@ -166,7 +166,7 @@ class IoTDeviceAdvisorClient(BaseClient):
         """
         Lists the tags attached to an IoT Device Advisor resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#list_tags_for_resource)
         """
 
@@ -174,14 +174,14 @@ class IoTDeviceAdvisorClient(BaseClient):
         self,
         *,
         suiteDefinitionId: str,
-        suiteDefinitionVersion: str = None,
-        suiteRunConfiguration: "SuiteRunConfigurationTypeDef" = None,
-        tags: Mapping[str, str] = None
+        suiteDefinitionVersion: str = ...,
+        suiteRunConfiguration: "SuiteRunConfigurationTypeDef" = ...,
+        tags: Mapping[str, str] = ...
     ) -> StartSuiteRunResponseTypeDef:
         """
         Starts a Device Advisor test suite run.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.start_suite_run)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.start_suite_run)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#start_suite_run)
         """
 
@@ -189,7 +189,7 @@ class IoTDeviceAdvisorClient(BaseClient):
         """
         Stops a Device Advisor test suite run that is currently running.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.stop_suite_run)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.stop_suite_run)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#stop_suite_run)
         """
 
@@ -197,7 +197,7 @@ class IoTDeviceAdvisorClient(BaseClient):
         """
         Adds to and modifies existing tags of an IoT Device Advisor resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#tag_resource)
         """
 
@@ -205,7 +205,7 @@ class IoTDeviceAdvisorClient(BaseClient):
         """
         Removes tags from an IoT Device Advisor resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#untag_resource)
         """
 
@@ -213,11 +213,11 @@ class IoTDeviceAdvisorClient(BaseClient):
         self,
         *,
         suiteDefinitionId: str,
-        suiteDefinitionConfiguration: "SuiteDefinitionConfigurationTypeDef" = None
+        suiteDefinitionConfiguration: "SuiteDefinitionConfigurationTypeDef" = ...
     ) -> UpdateSuiteDefinitionResponseTypeDef:
         """
         Updates a Device Advisor test suite.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.update_suite_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.update_suite_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#update_suite_definition)
         """
